@@ -29,6 +29,11 @@ DDCutilBrightness::~DDCutilBrightness()
 void DDCutilBrightness::detect()
 {
 #ifdef WITH_DDCUTIL
+
+    if (qEnvironmentVariableIntValue("POWERDEVIL_NO_DDCUTIL") > 0) {
+        return;
+    }
+
 #if DDCUTIL_VERSION >= QT_VERSION_CHECK(2, 0, 0)
     qCDebug(POWERDEVIL) << "Initializing ddcutil API (create ddcutil configuration file for tracing & more)...";
     static DDCA_Status init_status = -1; // negative indicates error condition
@@ -43,7 +48,7 @@ void DDCutilBrightness::detect()
     qCDebug(POWERDEVIL) << "Check for monitors using ddca_get_display_info_list2()...";
     // Inquire about detected monitors.
     DDCA_Display_Info_List *displays = nullptr;
-    ddca_get_display_info_list2(true, &displays);
+    ddca_get_display_info_list2(false, &displays);
     qCInfo(POWERDEVIL) << "[DDCutilBrightness]" << displays->ct << "display(s) were detected";
 
     for (auto &displayInfo : std::span(displays->info, displays->ct)) {
